sqitch v0.1.0 mix sqitch

Link to this section Summary

Functions

A task needs to implement run which receives a list of command line args

Link to this section Types

Link to this type cmd()
cmd() :: {Collectable.t(), exit_status :: non_neg_integer()}

Link to this section Functions

Link to this function run(args)
run(list()) :: cmd()

A task needs to implement run which receives a list of command line args.

Callback implementation for Mix.Task.run/1.